<p><%= t('.greeting', recipient: @email) %></p>

<% if @resource.try(:unconfirmed_email?) %>
  <p><%= t('.message', email: @resource.unconfirmed_email) %></p>
<% else %>
  <p><%= t('.message', email: @resource.email) %></p>
<% end %>
