<h2><%= t(".title", resource: resource.model_name.human) %></h2>

<%= simple_form_for(resource, as: resource_name, url: registration_path(resource_name), html: { method: :put }) do |f| %>
  <%= f.error_notification %>

  <div class="form-inputs">
    <%= f.input :email, required: true, autofocus: true %>

    <% if devise_mapping.confirmable? && resource.pending_reconfirmation? %>
      <p><%= t(".currently_waiting_confirmation_for_email", email: resource.unconfirmed_email) %></p>
    <% end %>

    <%= f.input :password,
                hint: t(".leave_blank_if_you_don_t_want_to_change_it"),
                required: false,
                input_html: { autocomplete: "new-password" } %>
    <%= f.input :password_confirmation,
                required: false,
                input_html: { autocomplete: "new-password" } %>
    <%= f.input :current_password,
                hint: t(".we_need_your_current_password_to_confirm_your_changes"),
                required: true,
                input_html: { autocomplete: "current-password" } %>
  </div>

  <div class="form-actions">
    <%= f.button :submit, t(".update") %>
  </div>
<% end %>

<h3><%= t(".cancel_my_account") %></h3>

<p><%= t(".unhappy") %> <%= link_to t(".cancel_my_account"), registration_path(resource_name), data: { confirm: t(".are_you_sure") }, method: :delete %></p>

<%= link_to t("devise.shared.links.back"), :back %>
